       IDENTIFICATION DIVISION.
       PROGRAM-ID. A12.
      *
      ****************************************************************
      * EINGABEDATEN: KUNDENDATEI
      *      AUFBAU:
      *        1 -  4 ( 4) ... KUNDENNUMMER
      *        5 - 24 (20) ... KUNDENNAME
      *          25   ( 1) ... SCHLSSEL ('1' = SOLL,
      *                                   '2' = HABEN)
      *       26 - 33 ( 8) ... UMSATZ (2 NACHKOMMASTELLEN)
      *          34   ( 1) ... SATZART ('1' = INLANDSUMSATZ,
      *                                 '2' = AUSLANDSUMSATZ)
      *
      * DIE EINGABEDATEN SIND NACH KUNDENNUMMERN AUFSTEIGEND SORTIERT.
      * PRO SCHLSSEL UND SATZART GIBT ES MAXIMAL 100 DATENSTZE.
      *---------------------------------------------------------------
      * AUSGABEDATEN: UMSATZLISTE
      *      AUFBAU:
      *        1 HAUPTBERSCHRIFT
      *        1 SPALTENBERSCHRIFT
      *        1 LEERZEILE
      *
      *        1 ZEILE FR JEDEN KUNDEN MIT
      *            KUNDENNAME
      *            UMSATZ - IN ENTSPRECHENDER SPALTE
      *                        (JE NACH SATZART UND SCHLSSEL)
      *
      *       AM ENDE DER VERARBEITUNG:
      *        1 LEERZEILE UND
      *        1 GESAMTSUMMENZEILE MIT DEN 4 SPALTENSUMMEN
      *
      * PRO SEITE MAXIMAL 60 ZEILEN
      *     (EINSCHL. BERSCHRIFTEN + LEERZEILEN),
      *     AUSGENOMMEN DIE LETZTE SEITE).
      * DIE SUMMENZEILE SOLL NIE UNMITTELBAR AUF DIE
      *     BERSCHRIFT FOLGEN.
      ****************************************************************
      * SORTIERREIHENFOLGE, SATZART UND SCHLSSEL SIND ZU PRFEN,
      * BEI JEDEM FEHLER IST AUF DIE KONSOLE EINE SPRECHENDE
      * FEHLERMELDUNG AUSZUGEBEN, DIE VERARBEITUNG JEDOCH NORMAL
      * FORTZUSETZEN.
      ****************************************************************
       ENVIRONMENT DIVISION.
       INPUT-OUTPUT SECTION.
       FILE-CONTROL.
           SELECT KUNDEN  ASSIGN TO KUNDEN.
           SELECT UMSATZ  ASSIGN TO UMSATZ.
           SELECT KONSOLE ASSIGN TO KONSOLE.
      *
       DATA DIVISION.
       FILE SECTION.
      *
       FD  KUNDEN.
       01  EBER.
           02 ENR    PIC X(4).
           02 ENAM   PIC X(20).
           02 ESCHL  PIC X(1).
           02 EUMS   PIC 9(6)V99.
           02 ESA    PIC X(1).
      *
       FD  UMSATZ.
       01  DBER      PIC X(85).
      *
       FD  KONSOLE.
       01  KBER      PIC X(25).
      *
       WORKING-STORAGE SECTION.
       77  ABU1      PIC X(85)  VALUE " K U N D E N N A M E
      -    "   I N L A N D                    A U S L A N D".
      *
       77  ABU2      PIC X(85)  VALUE "                                S
      -    "OLL           HABEN            SOLL           HABEN".
      *
       01  ABER.
           02 CC     PIC X.
           02 ANAM   PIC X(20).
           02 FILLER PIC X(6).
           02 AISOL  PIC ZZZ,ZZ9.99.
           02 FILLER PIC X(6).
           02 AIHAB  PIC ZZZ,ZZ9.99.
           02 FILLER PIC X(6).
           02 AASOL  PIC ZZZ,ZZ9.99.
           02 FILLER PIC X(6).
           02 AAHAB  PIC ZZZ,ZZ9.99.
      *
       01  ABS.
           02 CC     PIC X      VALUE SPACE.
           02 FILLER PIC X(23)  VALUE SPACE.
           02 ASUMIS PIC ZZ,ZZZ,ZZ9.99.
           02 FILLER PIC X(3)   VALUE SPACE.
           02 ASUMIH PIC ZZ,ZZZ,ZZ9.99.
           02 FILLER PIC X(3)   VALUE SPACE.
           02 ASUMAS PIC ZZ,ZZZ,ZZ9.99.
           02 FILLER PIC X(3)   VALUE SPACE.
           02 ASUMAH PIC ZZ,ZZZ,ZZ9.99.
      *
       01  KFEL.
           02 CC     PIC X      VALUE SPACE.
           02 KNR    PIC X(4).
           02 FILLER PIC X(1)   VALUE SPACE.
           02 KFM    PIC X(19).
      *
       77  ZMAX      PIC 99     VALUE 60  COMP-3.
       77  ZZ        PIC 99               COMP-3.
      *
       77  VSOL      PIC X(1)   VALUE "1".
       77  VHAB      PIC X(1)   VALUE "2".
       77  VILD      PIC X(1)   VALUE "1".
       77  VALD      PIC X(1)   VALUE "2".
      *
       77  FM1       PIC X(19)  VALUE "SORTIERFOLGEFEHLER ".
       77  FM2       PIC X(19)  VALUE "FALSCHER SCHLUESSEL".
       77  FM3       PIC X(19)  VALUE "FALSCHE SATZART    ".
      *
       77  NRALT     PIC X(4).
       77  LOW       PIC X(4)   VALUE LOW-VALUE.
      *
       77  SUMIS     PIC 9(11)V99         COMP-3.
       77  SUMIH     PIC 9(11)V99         COMP-3.
       77  SUMAS     PIC 9(11)V99         COMP-3.
       77  SUMAH     PIC 9(11)V99         COMP-3.
      *
       77  EOF       PIC 9      VALUE 0.
      *
       PROCEDURE DIVISION.
       ANFANG.
           OPEN INPUT  KUNDEN
                OUTPUT UMSATZ, KONSOLE.
      *
           PERFORM UPSTART.
           READ KUNDEN AT END MOVE 1 TO EOF.
           PERFORM WITH TEST BEFORE UNTIL EOF = 1
               IF NRALT NOT LESS ENR
               THEN MOVE FM1 TO KFM
                    PERFORM UPFEL
               ELSE MOVE ENR TO NRALT
               END-IF
               MOVE SPACE TO ABER
               IF ESCHL = VSOL
               THEN IF ESA = VILD
                    THEN MOVE EUMS TO AISOL
                         COMPUTE SUMIS = SUMIS + EUMS
                         PERFORM UPSCHR
                    ELSE IF ESA = VALD
                         THEN MOVE EUMS TO AASOL
                              COMPUTE SUMAS = SUMAS + EUMS
                              PERFORM UPSCHR
                         ELSE MOVE FM3 TO KFM
                              PERFORM UPFEL
                         END-IF
                    END-IF
               ELSE IF ESCHL = VHAB
                    THEN IF ESA = VILD
                         THEN MOVE EUMS TO AIHAB
                              COMPUTE SUMIH = SUMIH + EUMS
                              PERFORM UPSCHR
                         ELSE IF ESA = VALD
                              THEN MOVE EUMS TO AAHAB
                                   COMPUTE SUMAH = SUMAH + EUMS
                                   PERFORM UPSCHR
                              ELSE MOVE FM3 TO KFM
                                   PERFORM UPFEL
                              END-IF
                         END-IF
                    ELSE MOVE FM2 TO KFM
                         PERFORM UPFEL
                         IF ESA = VILD
                         THEN CONTINUE
                         ELSE IF ESA = VALD
                              THEN CONTINUE
                              ELSE MOVE FM3 TO KFM
                                   PERFORM UPFEL
                              END-IF
                         END-IF
                    END-IF
               END-IF
               READ KUNDEN AT END MOVE 1 TO EOF
               END-READ
           END-PERFORM.
           PERFORM UPENDVA.
      *
           CLOSE KUNDEN UMSATZ KONSOLE.
           STOP RUN.
      *
       UPFEL.
           MOVE ENR TO KNR.
           WRITE KBER FROM KFEL AFTER 1.
      *
       UPSTART.
           MOVE SPACE TO KFEL.
           COMPUTE ZZ = ZMAX.
           MOVE LOW TO NRALT.
           COMPUTE SUMIS = 0.
           COMPUTE SUMIH = 0.
           COMPUTE SUMAS = 0.
           COMPUTE SUMAH = 0.
      *
       UPENDVA.
           MOVE SPACE TO DBER.
           WRITE DBER AFTER 1.
           MOVE SUMIS TO ASUMIS.
           MOVE SUMIH TO ASUMIH.
           MOVE SUMAS TO ASUMAS.
           MOVE SUMAH TO ASUMAH.
           WRITE DBER FROM ABS AFTER 1.
      *
       UPSCHR.
           MOVE ENAM TO ANAM.
           IF ZZ NOT LESS ZMAX
               THEN PERFORM UPUEBER.
           WRITE DBER FROM ABER AFTER 1.
           COMPUTE ZZ = ZZ + 1.
      *
       UPUEBER.
           MOVE SPACE TO DBER.
           WRITE DBER AFTER PAGE.
           WRITE DBER FROM ABU1 AFTER 1.
           WRITE DBER FROM ABU2 AFTER 1.
           MOVE SPACE TO DBER.
           WRITE DBER AFTER 1.
           COMPUTE ZZ = 3.
