       IDENTIFICATION DIVISION.
       PROGRAM-ID. A40.
      *
      ****************************************************************
      * EINGABEDATEN: ARTIKELDATEI
      *      AUFBAU:
      *        1 -  4 ( 4) ... ARTIKELNUMMER
      *        5 - 24 (20) ... ARTIKELBEZEICHNUNG
      *       25 - 31 ( 7) ... EINZELPREIS
      *       32 - 36 ( 5) ... BESTANDSMENGE
      *       37 - 55 (19) ... SONSTIGE DATEN
      *
      * EINGABEDATEN: LSCHDATEI
      *      AUFBAU:
      *        1 -  4 ( 4) ... ARTIKELNUMMER
      *
      * BEIDE DATEIEN SIND AUFSTEIGEND SORTIERT NACH DER
      * ARTIKELNUMMER.
      * PRO ARTIKELNUMMER GIBT ES NUR 1 EINGABEDATENSATZ.
      *---------------------------------------------------------------
      * AUSGABEDATEN: AKTUALISIERTE ARTIKELDATEI
      *
      *               AKTUALISIERTE ARTIKELLISTE
      *
      *               FEHLERPROTOKOLL
      *                     ZU LSCHENDE ARTIKELNUMMER NICHT VORHANDEN
      *                     SORTIERFOLGEFEHLER IN DER LSCHDATEI
      ****************************************************************
       ENVIRONMENT DIVISION.
       INPUT-OUTPUT SECTION.
       FILE-CONTROL.
           SELECT ALTBAND ASSIGN TO ALTBAND.
           SELECT KLOESCH ASSIGN TO KLOESCH.
           SELECT NEUBAND ASSIGN TO NEUBAND.
           SELECT ARTLIST ASSIGN TO ARTLIST.
           SELECT FEHLER  ASSIGN TO FEHLER.
      *
       DATA DIVISION.
       FILE SECTION.
      *
       FD  ALTBAND.
       01  BBER.
           02 BNR     PIC X(4).
           02 BBEZ    PIC X(20).
           02 BPREIS  PIC 9(7).
           02 FILLER  PIC X(24).
      *
       FD  KLOESCH.
       01  KBER.
           02 KNR     PIC X(4).
      *
       FD  NEUBAND.
       01  BBERNEU    PIC X(55).
      *
       FD  ARTLIST.
       01  DBER       PIC X(51).
      *
       FD  FEHLER.
       01  FDBER      PIC X(36).
      *
       WORKING-STORAGE SECTION.
      **************************************
       01  BL1.
           05 BEOF    PIC X(1).
           05 BSORT1  PIC X(4).
       01  KL1.
           05 KEOF    PIC X(1).
           05 KSORT1  PIC X(4).
       01  VL1.
           05 VEOF    PIC X(1).
           05 VSORT1  PIC X(4).
      **************************************
       77  ABUEB      PIC X(51)  VALUE " ARTIKELLISTE".
      *
       01  ABER.
           02 CC      PIC X      VALUE SPACE.
           02 ANR     PIC X(4).
           02 FILLER  PIC X(3)   VALUE SPACE.
           02 ABEZ    PIC X(20).
           02 FILLER  PIC X(3)   VALUE SPACE.
           02 APREIS  PIC 9(7).
           02 FILLER  PIC X(4)   VALUE SPACE.
           02 ATEXT   PIC X(9)   VALUE SPACE.
      *
       77  ZZG        PIC 99     VALUE 66     COMP-3.
       77  ZZ         PIC 99     VALUE 99     COMP-3.
      *
       77  FUEB       PIC X(36)  VALUE " FEHLERPROTOKOLL".
      *
       01  FBER.
           02 CC      PIC X      VALUE SPACE.
           02 FNR     PIC X(4).
           02 FILLER  PIC X(1)   VALUE SPACE.
           02 FMELD   PIC X(30).
      *
       77  ZZGF       PIC 99     VALUE 66     COMP-3.
       77  ZZF        PIC 99     VALUE 99     COMP-3.
      *
       77  FEHL1      PIC X(30)  VALUE "ARTIKEL NICHT VORHANDEN".
       77  FEHL2      PIC X(30)  VALUE "SORTIERFOLGEFEHLER".
      *
       77  TEXTX      PIC X(9)   VALUE "GELOESCHT".
      *
       77  DZ         PIC 9                   COMP-3.
      * ----------------------------------
       PROCEDURE DIVISION.
       ANFANG.
           OPEN INPUT  ALTBAND, KLOESCH.
           OPEN OUTPUT NEUBAND, ARTLIST, FEHLER.
      *
           PERFORM UPROGVOR.
           PERFORM UPLESALTBAND.
           PERFORM UPLESKLOESCH.
           PERFORM WITH TEST BEFORE UNTIL DZ <= 0
               IF KL1 <= VL1
               THEN MOVE FEHL2 TO FMELD
                    PERFORM UPSCHRF
                    PERFORM UPLESKLOESCH
               ELSE PERFORM UPMISCH
               END-IF
           END-PERFORM.
      *
           CLOSE ALTBAND, KLOESCH,
                 NEUBAND, ARTLIST, FEHLER.
           STOP RUN.
      * ----------------------------------
       UPROGVOR.
           MOVE LOW-VALUE TO BEOF.
           MOVE LOW-VALUE TO KEOF.
           MOVE LOW-VALUE TO VL1.
           COMPUTE DZ = 2.
      * ----------------------------------
       UPLESALTBAND.
           READ ALTBAND
               AT END MOVE HIGH-VALUE TO BEOF
                      COMPUTE DZ = DZ - 1
               NOT AT END MOVE BNR TO BSORT1
           END-READ.
      * ----------------------------------
       UPLESKLOESCH.
           READ KLOESCH
               AT END MOVE HIGH-VALUE TO KEOF
                      COMPUTE DZ = DZ - 1
               NOT AT END MOVE KNR TO KSORT1
           END-READ.
      * ----------------------------------
       UPMISCH.
           IF BL1 < KL1
           THEN PERFORM UPSCHR
                WRITE BBERNEU FROM BBER
                PERFORM UPLESALTBAND
           ELSE IF BL1 = KL1
                THEN MOVE TEXTX TO ATEXT
                     PERFORM UPSCHR
                     PERFORM UPLESALTBAND
                     MOVE KSORT1 TO VSORT1
                     PERFORM UPLESKLOESCH
                ELSE MOVE FEHL1 TO FMELD
                     PERFORM UPSCHRF
                     MOVE KSORT1 TO VSORT1
                     PERFORM UPLESKLOESCH
                END-IF
           END-IF.
      * --------------------------------
       UPSCHR.
           MOVE BNR TO ANR.
           MOVE BBEZ TO ABEZ.
           MOVE BPREIS TO APREIS.
           IF ZZ NOT LESS ZZG THEN
               PERFORM UPUEB
           END-IF.
           WRITE DBER FROM ABER AFTER 1.
           COMPUTE ZZ = ZZ + 1.
           MOVE SPACE TO ABER.
      * --------------------------------
       UPSCHRF.
           MOVE KNR TO FNR.
           IF ZZF NOT LESS ZZGF THEN
               PERFORM UPUEBF
           END-IF.
           WRITE FDBER FROM FBER AFTER 1.
           COMPUTE ZZF = ZZF + 1.
      * --------------------------------
       UPUEB.
           WRITE DBER FROM ABUEB AFTER PAGE.
           MOVE SPACE TO DBER.
           WRITE DBER AFTER 1.
           COMPUTE ZZ = 2.
      * --------------------------------
       UPUEBF.
           WRITE FDBER FROM FUEB AFTER PAGE.
           MOVE SPACE TO FDBER.
           WRITE FDBER AFTER 1.
           COMPUTE ZZF = 2.
